Learn R Programming

zenplots (version 0.0-1)

plot_region: Setting up Plot Region for Graphics Functions

Description

Auxiliary function for setting up the plot region of 1d and 2d graphics plots.

Usage

plot_region(xlim, ylim, plot... = NULL)

Arguments

xlim

x-axis limits.

ylim

y-axis limits.

plot...

arguments passed to plot().

Value

invisible().

Details

This is an auxiliary function used by the provided graphics-related 1d and 2d plots.

See Also

plots_graphics

Examples

Run this code
# NOT RUN {
plot_region
# }

Run the code above in your browser using DataLab