Learn R Programming

zenplots (version 0.0-1)

scaling: Scaling Data

Description

Auxiliary function to scale data.

Usage

scale01(x, method = c("columnwise", "all", "pobs"), ...)

Arguments

x

matrix, data.frame or list of vectors containing the data to be scaled to \([0,1]\).

method

character string indicating the scaling method to be used. Available are:

"columnwise":

scales x columnwise.

"all":

scales all components of x simultaneously.

"pobs":

applies columnwise the respective empirical distribution function to x; see the R\ package ``copula'' for more details.

...

additional arguments passed to rank() (for method = "pobs") and range() (for all other methods).

Value

scale01() returns an object of the same type as x, but scaled to lie in \([0,1]\). Note that NA values are passed through.

Examples

Run this code
# NOT RUN {
## Implementation
scale01
# }

Run the code above in your browser using DataLab