Determining the indices of the x and y variables of the current plot.
Usage
plot_indices(zargs)
Arguments
zargs
argument list as passed from zenplot().
This must at least contain vars and num; see
zenplot() for an explanation of these variables.
Value
A numeric(2) containing the indices of the x and y variables to
be plotted in the current plot (the plot with number num). If
the current plot is a 2d plot, the same variable is used twice.
Details
This is an auxiliary function useful, for example, when writing
user-provided 1d and 2d plot functions.