powered by
Auxiliary function for setting up the plot region of 1d and 2d graphics plots.
plot_region(xlim, ylim, plot... = NULL)
x-axis limits.
y-axis limits.
arguments passed to plot().
plot()
invisible().
invisible()
This is an auxiliary function used by the provided graphics-related 1d and 2d plots.
plots_graphics
# NOT RUN { plot_region # }
Run the code above in your browser using DataLab